==> nuiton-csv-2.6.12.1-sources.jar: org/nuiton/util/csv/ImportSetErrorInfo.java <==
package org.nuiton.util.csv;

/*
 * #%L
 * Nuiton Utils :: Nuiton Csv
 * $Id: ImportSetErrorInfo.java 2421 2012-09-18 13:50:54Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-csv-2.6.12.1/src/main/java/org/nuiton/util/csv/ImportSetErrorInfo.java $
 * %%
 * Copyright (C) 2011 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

/**
 * Exception to be thrown when a set error occurs at import time.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.3
 */
public class ImportSetErrorInfo<E> extends AbstractImportErrorInfo<E> {

    protected final String value;

    protected final Object parsedValue;

    public ImportSetErrorInfo(ImportRow<E> row,
                              ImportableColumn<E, Object> field,
                              String value,
                              Object parsedValue,
                              Throwable cause) {
        super(row, field, cause);
        this.value = value;
        this.parsedValue = parsedValue;
    }

    public String getValue() {
        return value;
    }

    public Object getParsedValue() {
        return parsedValue;
    }
}

==> nuiton-csv-2.7-sources.jar: org/nuiton/util/csv/ImportSetErrorInfo.java <==
package org.nuiton.util.csv;

/*
 * #%L
 * Nuiton Utils :: Nuiton Csv
 * $Id: ImportSetErrorInfo.java 2586 2013-07-20 06:57:12Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-utils-2.7/nuiton-csv/src/main/java/org/nuiton/util/csv/ImportSetErrorInfo.java $
 * %%
 * Copyright (C) 2011 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

/**
 * Exception to be thrown when a set error occurs at import time.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.3
 * @deprecated since 2.7, use now the http://maven-site.nuiton.org/nuiton-csv project, This module will be remove in version 3.0
 */
@Deprecated
public class ImportSetErrorInfo<E> extends AbstractImportErrorInfo<E> {

    protected final String value;

    protected final Object parsedValue;

    public ImportSetErrorInfo(ImportRow<E> row,
                              ImportableColumn<E, Object> field,
                              String value,
                              Object parsedValue,
                              Throwable cause) {
        super(row, field, cause);
        this.value = value;
        this.parsedValue = parsedValue;
    }

    public String getValue() {
        return value;
    }

    public Object getParsedValue() {
        return parsedValue;
    }
}
